;; -*-scheme-*-
;;
;;  Richard -Gilligan- Uschold
;; These are help strings for each TXF code. See taxtxf.scm and
;; txf-export.scm
;;
;; (n <- TurboTax      (N <- IRS
;;
;; Changes in this file should also be applied on gnucash-docs/help/C/Help_txf-categories.xml
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2 of
;; the License, or (at your option) any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program; if not, contact:
;;
;; Free Software Foundation           Voice:  +1-617-542-5942
;; 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652
;; Boston, MA  02110-1301,  USA       gnu@gnu.org
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define-module (gnucash locale us tax txf-help))

(export txf-help-strings)
(define txf-help-strings
  '(
    (H001 . "Categories marked with a \"&lt;\" or a \"^\", require a Payer identification to be exported.  \"&lt;\" indicates that the name of this account is exported as this Payer ID.  Typically, this is a bank, stock, or mutual fund name.")
    (H002 . "Categories marked with a \"&lt;\" or a \"^\", require a Payer identification to be exported.  \"^\" indicates that the name of the PARENT of this account is exported as this Payer ID.  Typically, this is a bank, stock, or mutual fund name.")
    (H003 . "Categories marked with a \"#\" are not fully implemented yet!  Do not use these codes!")
    (N000 . "This is a dummy category and only shows up on the tax report, but is not exported.")
    (H256 . "Form 1040 is the main form of your tax return.")
    (N257 . "Miscellaneous income such as: a hobby or a farm you operate mostly for recreation and pleasure, jury duty pay. Exclude self employment income, gambling winnings, prizes and awards.")
    (N258 . "Amounts you receive from your employer while you are sick or injured are part of your salary or wages. Exclude workers' compensation, accident or health insurance policy benefits, if you paid the premiums.")
    (N259 . "The amount of prizes and awards that are not for services performed. Included is the fair market value of merchandise won on game shows.")
    (N260 . "Refund of state or local income tax refund (or credit or offset) which you deducted or took a credit for in an earlier year. You should receive a statement, Form 1099-G. Not reportable if you didn't itemize last year.")
    (N261 . "Amounts received as alimony or separate maintenance.  Note: child support is not considered alimony.")
    (N479 . "Total unemployment compensation paid to you this year. Reported on Form 1099-G.")
    (N262 . "Contribution to a qualified IRA.  If you or your spouse are covered by a company retirement plan, this amount could be limited or eliminated.")
    (N481 . "Contribution of a working spouse to a qualified IRA. If you or your spouse are covered by a company retirement plan, the deductible contribution could be limited or eliminated.")
    (N263 . "Contributions to a Keogh or HR 10 plan of a sole proprietor or a partnership.")
    (N516 . "Spouse Contributions to a Keogh or HR 10 plan of a sole proprietor or a partnership.")
    (N517 . "Contributions made to a simplified employee pension plan (SEP-IRA).")
    (N518 . "Spouse contributions made to a simplified employee pension plan (SEP-IRA).")
    (N264 . "Amounts payed as alimony or separate maintenance.  Note: child support is not considered alimony.")
    (N265 . "Penalty on Early Withdrawal of Savings from CD's or similar instruments. This is reported on Form 1099-INT or Form 1099-OID.")
    (N266 . "The part of any monthly benefit under title II of the Social Security Act. These will be reported on Form SSA-1099.")
    (N267 . "Qualified moving expense reimbursements paid directly to you by an employer.")
    (N521 . "The quarterly payments you made on your estimated Federal income tax (Form 1040-ES). Include any overpay from your previous year return that you applied to your estimated tax. NOTE: If a full year (Jan 1, YEAR to Dec 31, YEAR) is specified, GnuCash adjusts the date to Mar 1, YEAR to Feb 28, YEAR+1. Thus, the payment due Jan 15 is exported for the correct year.")
    (N269 . "Fringe benefits you receive in connection with the performance of your services are included in your gross income as compensation. Examples: Accident or Health Plan, Educational Assistance, Group-Term Life Insurance, Transportation (company car).")
    (N482 . "IRA contribution for a non-working spouse.")
    (N483 . "Spouse's part of any monthly benefit under title II of the Social Security Act. These will be reported on Form SSA-1099.")
    (N519 . "The part of tier I railroad retirement benefits, which are treated as a social security benefits. These will be reported on Form RRB-1099.")
    (N520 . "Spouse's part of tier I railroad retirement benefits, which are treated as a social security benefits. These will be reported on Form RRB-1099.")
    (N636 . "The amount of interest you paid this year on qualified student loans.")
    (H270 . "Schedule A is used to report your itemized deductions.")
    (N271 . "Amounts paid for subscriptions to magazines or services that are directly related to the production or collection of taxable income.  (exapmle: subscriptions to investment publications, stock newsletters, etc.).")
    (N272 . "Gambling losses, but only to the extent of gambling winnings reported on Form 1040. Note: not subject to the 2% AGI of limitation.")
    (N273 . "Prescription medicines, eyeglasses, contact lenses, hearing aids. Over-the-counter medicines are not deductable.")
    (N274 . "Lodging expenses while away from home to receive medical care in a hospital or a medical care facility related to a hospital. Do not include more than $50 a night for each eligible person. Ambulance service and other travel costs to get medical care.")
    (N275 . "State income taxes paid this year for a prior year. Includ any part of a prior year refund that you chose to have credited to this years state income taxes.")
    (N544 . "Local income taxes that were not withheld from your salary, such as local income taxes you paid this year for a prior year.")
    (N276 . "Include taxes (state, local, or foreign) you paid on real estate you own that was not used for business, but only if the taxes are based on the assessed value of the property. Do not include taxes charged for improvements that tend to increase the value of your property (for example, an assessment to build a new sidewalk).")
    (N535 . "Enter personal property tax you paid, but only if it is based on value alone. Example: You paid a fee for the registration of your car. Part of the fee was based on the car s value and part was based on its weight. You may deduct only the part of the fee that is based on the car s value.")
    (N277 . "Other taxes paid not included under state and local income taxes, real estate taxes, or personal property taxes. You may want to take a credit for the foreign tax instead of a deduction.")
    (N280 . "Contributions or gifts by cash or check you gave to organizations that are religious, charitable, educational, scientific, or literary in purpose. You may also deduct what you gave to organizations that work to prevent cruelty to children or animals. For donations of $250 or more, you must have a statement from the charitable organization showing the amount donated and the value of goods or services you received.")
    (N485 . "The fair market value of donated property, such as used clothing or furniture.")
    (N281 . "Fees you paid for preparation of your tax return, including fees paid for filing your return electronically.")
    (N282 . "Investment interest is interest paid on money you borrowed that is allocable to property held for investment. It does not include any interest allocable to passive activities or to securities that generate tax-exempt income.")
    (N283 . "Home mortgage interest and points reported to you on Form 1098. The interest could be on a first or second mortgage, home equity loan, or refinanced mortgage.")
    (N284 . "Generally, you must deduct points you paid to refinance a mortgage over the life of the loan. If you used part of the proceeds to improve your main home, you may be able to deduct the part of the points related to the improvement in the year paid. See Pub. 936 Use this line for points not reported on Form 1098.")
    (N484 . "Insurance premiums for medical and dental care, medical doctors, dentists, eye doctors, surgeons, X-ray, laboratory services, hospital care, etc. See IRS Pub 502.")
    (N486 . "Safety equipment, small tools, and supplies you needed for your job; Uniforms required by your employer and which you may not usually wear away from work; subscriptions to professional journals; job search expenses; certain educational expenses. You may need to file Form 2106.")
    (N523 . "Other miscellaneous itemized deductions that are not reduced by 2% of adjusted gross income, such as casualty and theft losses from income-producing, amortizable bond premium on bonds acquired before October 23, 1986, federal estate tax on income in respect to a decedent, certain unrecovered investment in a pension, impairment-related work expenses of a disabled person.")
    (N522 . "State estimated tax payments made this year.")
    (N545 . "Home mortgage interest paid, for which you did not receive a Form 1098 from the recipient. The interest could be on a first or second mortgage, home equity loan, or refinanced mortgage.")
    (H285 . "Schedule B is used to report your interest and dividend income.")
    (N524 . "Interest the buyer paid you on a mortgage or other form of seller financing, for your home or other property and the buyer used the property as a personal residence. There are several categories of interest, be sure you select the correct one!")
    (N286 . "Ordinary dividends from mutual funds, stocks, etc., are reported to you on a 1099-DIV.  Note: these are sometimes called short term capital gain distributions. Do not include (long term) capital gain distributions or non-taxable dividends here, these go on Sched D")
    (N287 . "Taxable interest includes interest you receive from bank accounts, credit unions, loans you made to others. There are several categories of interest, be sure you select the correct one!")
    (N288 . "Interest on U.S. obligations, such as U.S. Treasury bills, notes, and bonds issued by any agency of the United States. This income is exempt from all state and local income taxes. There are several categories of interest, be sure you select the correct one!")
    (N289 . "Interest on bonds or notes of states, counties, cities, the District of Columbia, or possessions of the United States is generally free of federal income tax (but you may pay state income tax). There are several categories of interest, be sure you select the correct one!")
    (N290 . "Interest income from a qualified tax-exempt private activity bond is not taxable if it meets all requirements. This income is included on your Schedule B as non-taxable interest income. There are several categories of interest, be sure you select the correct one!")
    (N487 . "Some mutual funds pay shareholders non-taxable dividends. The amount of non-taxable dividends are indicated on your monthly statements or Form 1099-DIV.")
    (N488 . "Sometimes called long term capital gain distributions. These are from mutual funds, other regulated investment companies, or real estate investment trusts.  These are reported on your monthly statements or Form 1099-DIV. Note: short term capital gain distributions are reported on Sched B as ordinary dividends")
    (N489 . "Non-taxable interest income other than from bonds or notes of states, counties, cities, the District of Columbia, or a possession of the United States, or from a qualified private activity bond. There are several categories of interest, be sure you select the correct one!")
    (N490 . "Interest income that is taxed on your federal return, but not on your state income tax return - other than interest paid on U.S. obligations. There are several categories of interest, be sure you select the correct one!")
    (N491 . "Interest income that is not taxed on your federal return, but is taxed on your state income tax return - other than interest income from state bonds or notes, the District of Columbia, or a possession of the United States. There are several categories of interest, be sure you select the correct one!")
    (N492 . "Interest income from Original Issue Discount (OID) bonds will be reported to you on Form 1099-OID. There are several categories of interest, be sure you select the correct one!")
    (H291 . "Schedule C is used to report income from self-employment. Use a separate Schedule C to report income and expenses from different businesses.")
    (N293 . "The amount of gross receipts from your trade or business. Include amounts you received in your trade or business that were properly shown on Forms 1099-MISC.")
    (N294 . "Total business meal and entertainment expenses. Business meal expenses are deductible only if they are (a) directly related to or associated with the active conduct of your trade or business, (b) not lavish or extravagant, and (c) incurred while you or your employee is present at the meal.")
    (N493 . "If you are a merchant, use the cost of all merchandise you bought for sale. If you are a manufacturer or producer, this includes the cost of all raw materials or parts purchased for manufacture into a finished product. You must exclude the cost of merchandise you withdraw for your personal or family use.")
    (N494 . "Labor costs are usually an element of cost of goods sold only in a manufacturing or mining business. In a manufacturing business, labor costs that are properly allocable to the cost of goods sold include both the direct and indirect labor used in fabricating the raw material into a finished, saleable product.")
    (N495 . "Materials and supplies, such as hardware and chemicals, used in manufacturing goods are charged to cost of goods sold. Those that are not used in the manufacturing process are treated as deferred charges. You deduct them as a business expense when you use them.")
    (N496 . "Other costs incurred in a manufacturing or mining process that you charge to your cost of goods sold are containers, freight-in, overhead expenses.")
    (N296 . "Credits you allow customers for returned merchandise and any other allowances you make on sales.")
    (N297 . "The total amount of salaries and wages for the tax year. Do not include amounts paid to yourself.")
    (N298 . "Accountant's or legal fees for tax advice related to your business and for preparation of the tax forms related to your business.")
    (N299 . "The amount paied to rent or lease vehicles, machinery, or equipment, for your business. If you leased a vehicle for a term of 30 days or more, you may have to reduce your deduction by an amount called the inclusion amount. See Pub. 463.")
    (N300 . "The amounts paid to rent or lease real estate or  property, such as office space in a building.")
    (N301 . "The cost of supplies not reported under Cost Of Goods Sold.")
    (N302 . "Other costs not specified on other lines of Schedule C, such as: Clean-fuel vehicles and refueling property; Donations to business organizations; Educational expenses; Environmental cleanup costs; Impairment-related expenses; Interview expense allowances; Licenses and regulatory fees; Moving machinery; Outplacement services; Penalties and fines you pay for late performanc or nonperformance of a contract; Subscriptions to trade or professional publications.")
    (N303 . "The amounts from finance reserve income, scrap sales, bad debts you recovered, interest (such as on notes and accounts receivable), state gasoline or fuel tax refunds you got this year, prizes and awards related to your trade or business, and other kinds of miscellaneous business income.")
    (N304 . "The amounts paid for advertising your trade or business in newspapers, publications, radio or television. Also include the cost of brochures, business cards, or other promotional material.")
    (N305 . "Include debts and partial debts from sales or services that were included in income and are definitely known to be worthless.")
    (N306 . "You can deduct the actual expenses of running your car or truck, or take the standard mileage rate.")
    (N307 . "The amounts of commissions or fees paid to independent contractors (nonemployees) for their services.")
    (N308 . "Contributions to employee benefit programs that are not an incidental part of a pension or profit-sharing plan. Examples are accident and health plans, group-term life insurance, and dependent care assistance programs.")
    (N309 . "The amounts for depletion. If you have timber depletion, attach Form T.  See Pub. 535.")
    (N310 . "Premiums paid for business insurance. Do not include amounts paid for employee accident and health insurance. nor amounts credited to a reserve for self-insurance or premiums paid for a policy that pays for your lost earnings due to sickness or disability. See Pub. 535.")
    (N311 . "The interest you paid to banks or other financial institutions for which you received a Form 1098, for a mortgage on real property used in your business (other than your main home).")
    (N312 . "The interest you paid for which you did not receive a Form 1098 (perhaps someone else did, and you are liable too), for a mortgage or other loans for your business.")
    (N313 . "The cost of consumable office supplies such as business cards, computer supplies, pencils, pens, postage stamps, rental of postal box or postage machines, stationery, Federal Express and UPS charges, etc.")
    (N314 . "You can set up and maintain the following small business retirement plans for yourself and your employees, such as: SEP (Simplified Employee Pension) plans; SIMPLE (Savings Incentive Match Plan for Em-ployees) plans; Qualified plans (including Keogh or H.R. 10 plans). You deduct contributions you make to the plan for yourself on Form 1040.")
    (N315 . "The cost of repairs and maintenance. Include labor, supplies, and other items that do not add to the value or increase the life of the property. Do not include the value of your own labor. Do not include amounts spent to restore or replace property; they must be capitalized.")
    (N316 . "Include the following taxes: State and local sales taxes imposed on you as the seller of goods or services; Real estate and personal property taxes on business assets; Social security and Medicare taxes paid to match required withholding from your employees' wages; Also, Federal unemployment tax paid; Federal highway use tax.")
    (N317 . "Expenses for lodging and transportation connected with overnight travel for business while away from your tax home.")
    (N318 . "The costs of electricity, gas, telephone, etc. for your business property.")
    (H320 . "Schedule D is used to report gains and losses from the sale of capital assets.")
    (N321 . "Short term gain or loss from the sale of a security.")
    (N323 . "Long term gain or loss from the sale of a security.")
    (N673 . "Short term or long term gain or loss from the sale of a security; for use when only the date sold and net sales amount are available and the date acquired and cost basis information is not available and will be separately added in the tax software.")
    (H325 . "Schedule E is used to report income or loss from rental real estate, royalties, and residual interest in REMIC's. Use a different copy for each rental or royalty. Use the Schedule K-1 categories for partnership rental income and loss amounts.")
    (N326 . "The amounts received as rental income from real estate (including personal property leased with real estate) but you were not in the real estate business. (If you are in the buisness of renting personal property, use Schedule C.)")
    (N327 . "Royalties recieved from oil, gas, or mineral properties (not including operating interests); copyrights; and patents.")
    (N328 . "Amounts paid to advertise rental unit(s) in newspapers or other media or paid to realtors to obtain tenants.")
    (N329 . "The ordinary and necessary amounts of auto and travel expenses related to your rental activities, including 50% of meal expenses incurred while traveling away from home.")
    (N330 . "The amounts paid for cleaning services (carpet, drapes), cleaning supplies, locks and keys, pest control, pool service, and general cost of upkeep of the rental property.")
    (N331 . "The amounts paid as Commissions to realtors or management companies to collect rent.")
    (N332 . "Insurasnce premiums paid for fire, theft, liability.")
    (N333 . "The amounts of fees for tax advice and the preparation of tax forms related to your rental real estate or royalty properties.")
    (N334 . "Interest paid to banks or other financial institutions for a mortgage on your rental property, and you recieved a Form 1098.")
    (N335 . "Interest paid for a mortgage on your rental property, not paid to banks or other financial institutions or you did not recieve a Form 1098.")
    (N336 . "You may deduct the cost of repairs made to keep your property in good working condition. Repairs generally do not add significant value to the property or extend its life.")
    (N337 . "Miscellaneous items needed to maintain the property, such as: brooms, cleaning supplies, nails, paint brushes, etc.")
    (N338 . "The amounts paid for real estate and personal property taxes. Also include the portion of any payroll taxes you paid for your employees.")
    (N339 . "The costs of electricity, gas, telephone, etc. for your rental property.")
    (N341 . "Other expenses that are not listed on other tax lines of Schedule E.  These might include the cost of gardening and/or snow removal services, association dues, bank charges, etc.")
    (N502 . "The amount of fees to a manager or property management company to oversee your rental or royalty property.")
    (H343 . "Schedule F is used to report farm income and expense. Use a different copy of Schedule F for each farm you own.")
    (N344 . "The amounts you paid for farm labor. Do not include amounts paid to yourself.  Count the cost of boarding farm labor but not the value of any products they used from the farm. Count only what you paid house-hold help to care for farm laborers.")
    (N345 . "Amounts you paid for repairs and maintenance of farm buildings, machinery, and equipment. You can also include what you paid for tools of short life or minimal cost, such as shovels and rakes.")
    (N346 . "The interest you paid to banks or other financial institutions for which you received a Form 1098, for a mortgage on real property used in your farming business (other than your main home). If you paid interest on a debt secured by your main home, and any proceeds from that debt were used in your farming operation, refer to IRS Pub 225.")
    (N347 . "The interest you paid for which you did not receive a Form 1098 (perhaps someone else did, and you are liable too), for a mortgage or other loans for your farm business.")
    (N348 . "Amounts paid to rent or lease property such as pasture or farm land.")
    (N349 . "The business portion of your rental cost, for rented or leased vehicles, machinery, or equipment. But if you leased a vehicle for a term of 30 days or more, you may have to reduce your deduction by an inclusion amount. For details, see the instructions for Schedule C (Form 1040).")
    (N350 . "The cost of feed for your livestock. Generally, you cannot currently deduct ex-penses for feed to be consumed by your livestock in a later tax year. See insctuctions for Schedule F.")
    (N351 . "The amounts paid for seeds and plants purchased for farming.")
    (N352 . "The cost of fertilizer, lime, and other materials applied to farm land to enrich, neutralize, or condition it. You can also deduct the cost of applying these materials. However, see Prepaid Farm Supplies, in Pub 225, for a rule that may limit your deduction for these materials.")
    (N353 . "Livestock supplies and other supplies, including bedding, office supplies, etc.")
    (N355 . "The costs of veterinary services, medicine and breeding fees.")
    (N356 . "The costs of gas, fuel, oil, etc. for farm equipment.")
    (N357 . "Amounts paid for storage and warehousing of crops, grains, etc.")
    (N358 . "Real estate and personal property taxes on farm business assets; Social security and Medicare taxes you paid to match what you are required to withhold from farm employees' wages and any Federal unemployment tax paid; Federal highway use tax.")
    (N359 . "Premiums paid for farm busines insurance, such as: fire, storm, crop, theft and liability protection of farm assets.  Do not include premiums for employee accident and health insurance.")
    (N360 . "Amounts you paid for gas, electricity, water, etc., for business use on the farm. Do not include personal utilities. You cannot deduct the base rate (including taxes) of the first telephone line into your residence, even if you use it for business.")
    (N361 . "The costs of freight or trucking of produce or livestock.")
    (N362 . "Your expenses for soil or water conservation or for the prevention of erosion of land used in farming. To take this deduction, your expenses must be consistent with a plan approved by the Natural Resources Conservation Service (NRCS) of the Department of Agriculture.")
    (N363 . "Enter your deduction for contributions to employee pension, profit-sharing, or annuity plans. If the plan included you as a self-employed person, see the instructions for Schedule C (Form 1040).")
    (N364 . "Contributions to employee benefit programs, such as accident and health plans, group-term life insurance, and dependent care assistance programs. Do not include contributions  that are a incidental part of a pension or profit-sharing plan.")
    (N365 . "Include all ordinary and necessary farm expenses not deducted elsewhere on Schedule F, such as advertising, office supplies, etc. Do not include fines or penalties paid to a government for violating any law.")
    (N366 . "Chemicals used in operating your farm, such as insect sprays and dusts.")
    (N367 . "Amounts you paid for custom hire (machine work) (the machine operator furnished the equipment).  Do not include amounts paid for rental or lease of equipment you operated yourself.")
    (N368 . "Amounts you received from the sale of livestock, produce, grains, and other products you raised.")
    (N369 . "Amounts you received from the sales of livestock and other items you bought specifically for resale. Do not include sales of livestock held for breeding, dairy purposes, draft, or sport.  These are reported on Form 4797, Sales of Business Property.")
    (N370 . "The income you received for custom hire (machine work).")
    (N371 . "Distributions received from a cooperative. This includes patronage dividends, nonpatronage distributions, per-unit retain allocations, and redemption of nonqualified notices and perunit retain allocations. Reported on Form 1099-PATR.")
    (N372 . "Government payments received for: price support payments, market gain from the repayment of a secured Commodity Credit Corporation (CCC) loan for less than the original loan amount, diversion payments, cost-share payments (sight drafts), payments in the form of materials (such as fertilizer or lime) or services (such asgrading or building dams). Reported on Form 1099-G.")
    (N373 . "Generally, you do not report CCC loan pro-ceeds as income. However, if you pledge part or all of your production to secure a CCC loan, you may elect to report the loan proceeds as income in the year you receive them, instead of the year you sell the crop.")
    (N374 . "The amount forfeited or repaid with certificates, even if you reported the loan proceeds as income.  See IRS Pub 225.")
    (N375 . "You generally include crop insurance proceeds in the year you receive them. Treat as crop insurance proceeds the crop disaster payments you receive from the federal government.")
    (N376 . "If you use the cash method of accounting and receive crop insurance proceeds in the same tax year in which the crops are damaged, you can choose to postpone reporting the proceeds as income until the following tax year. A statement must also be attached to your return.  See IRS Pub 225.")
    (N377 . "Illegal Federal irrigation subsidies, bartering income, income from discharge of indebtedness, state gasoline or fuel tax refund, the gain or loss on the sale of commodity futures contracts, etc.")
    (N378 . "The cost or other basis of the livestock and other items you actually sold.")
    (N543 . "The business portion of car or truck expenses, such as, for gasoline, oil, repairs, insurance, tires, license plates, etc.")
    (H565 . "Schedule H is used to report Federal employment taxes on cash wages paid this year to household employees.  Federal employment taxes include social security, Medicare, withheld Federal income, and Federal unemployment (FUTA) taxes.")
    (N567 . "For household employees to whom you paid $1,100 (as of 1999) or more each of cash wages that are subject to social security and Medicare taxes. To find out if the wages are subject to these taxes, see the instructions for Schedule H.")
    (N568 . "Federal income tax withheld from total cash wages paid to household employees during the year.")
    (H380 . "Form 2106 is used to deduct employee business expenses. You must file this form if you were reimbursed by your employer or claim job-related travel, transportation, meal, or entertainment expenses. Use a separate Form 2106 for your spouse's expenses.")
    (N381 . "Cost of tuition, books, supplies, laboratory fees, and similar items, and certain transportation costs if the education maintains or improves skills required in your present work or is required by your employer or the law to keep your salary, status, or job, and the requirement serves a business purpose of your employer. Expenses are not decutable if they are needed to meet the minimum educational requirements to qualify you in your work or business orwWill lead to qualifying you in a new trade or business.")
    (N382 . "Total annual expenses for gasoline, oil, repairs, insurance, tires, license plates, or similar items.")
    (N383 . "Travel expenses are those incurred while traveling away from home for your employer. The cost of getting to and from your business destination (air, rail, bus, car, etc.), taxi fares, baggage charges, and cleaning and laundry expenses. Note: meal and entertainment expenses are not included here.")
    (N384 . "Local transportation expenses are the expenses of getting from one workplace to another when you are not traveling away from home. They include the cost of transportation by air, rail, bus, taxi, and the cost of using your car. Generally, the cost of commuting to and from your regular place of work is not deductible.")
    (N385 . "Other job-related expenses, including expenses for business gifts, trade publications, etc.")
    (N386 . "Allowable meals and entertainment expense, including meals while away from your tax home overnight and other business meals and entertainment.")
    (N387 . "Reimbursement for business expenses from your employer that is NOT included on your Form W-2. Note: meals and entertainment are NOT included here.")
    (N388 . "Reimbursement for meal and entertainment expenses from your employer that is NOT included on your Form W-2.")
    (N389 . "Fees to employment agencies and other costs to look for a new job in your present occupation, even if you do not get a new job.")
    (N390 . "cost and upkeep of work clothes, if you must wear them as a condition of your employment, and the clothes are not suitable for everyday wear. Include the cost of protective clothing required in your work, such as safety shoes or boots, safety glasses, hard hats, and work gloves.")
    (N391 . "Your use of the business part of your home must be: exclusive, regular, for your trade or business, AND The business part of your home must be one of the following: your principal place of business, a place where you meet or deal with patients, clients, or customers in the normal course of your trade or business, or a separate structure (not attached to yourhome) you use in connection with your trade or business. Additionally, Your business use must be for the convenience of your employer, and You do not rent all or part of your home to your employer and use the rented portion to perform services as an employee. See IRS Pub 587.")
    (N392 . "Home Sale worksheets (replaces Form 2119) are used to report the sale of your personal residence. See IRS Pub 523.")
    (N393 . "The selling price is the total amount you receive for your home. It includes money, all notes, mortgages, or other debts assumed by the buyer as part of the sale, and the fair market value of any other property or any services you receive. Reported on Form 1099-S.")
    (N394 . "Selling expenses include commissions, advertising fees, legal fees, title insurance, and loan charges paid by the seller, such as loan placement fees or \"points.\"")
    (N396 . "Fixing-up expenses are decorating and repair costs that you paid to sell your old home. For example, the costs of painting the home, planting flowers, and replacing broken windows are fixing-up expenses. Fixing-up expenses must meet all the following conditions. The expenses: Must be for work done during the 90-day period ending on the day you sign the contract of sale with the buyer; Must be paid no later than 30 days after the date of sale; Cannot be deductible in arriving at your taxable in-come; Must not be used in figuring the amount realized; and Must not be capital expenditures or improvements.")
    (N397 . "The cost of your new home includes costs incurred within the replacement period (beginning 2 years before and ending 2 years after the date of sale) for the following items: Buying or building the home; Rebuilding the home; and Capital improvements or additions.")
    (H400 . "Form 2441 is used to claim a credit for child and dependent care expenses.")
    (N401 . "The total amount you actually paid to the care provider. Also, include amounts your employer paid to a third party on your behalf.")
    (N402 . "The cost of services needed to care for the qualifying person as well as to run the home.  They include the services of a babysitter, cleaning person, cook, maid, or housekeeper if the services were partly for the care of the qualifying person.")
    (H403 . "Form 3903 is used to claim moving expenses.")
    (N406 . "The amount you paid to pack, crate and move your household goods and personal effects.  You may include the cost to store and insure household goods and personal effects within any period of 30 days in a row after the items were moved from your old home.")
    (N407 . "The amount you paid to travel from your old home to your new home. This includes transportation and lodging on the way. Although not all members of your household must travel together, you may only include expenses for one trip per person. Do not include meals.")
    (H503 . "Form 4137 is used to compute social security and Medicare tax owed on tips you did not report to your employer.")
    (N505 . "The amount of tips you did not report to your employer.")
    (H412 . "Form 4684 is used to report gains and losses from casualties and thefts.")
    (N413 . "Cost or other basis usually means original cost plus improvements. Subtract any postponed gain from the sale of aprevious main home. Special rules applyto property received as a gift or inheritance. See Pub  551, Basis of Assets, for details.")
    (N414 . "The amount of insurance or other reimbursement you received expect to receive.")
    (N415 . "The fair market value (FMV) is the price at which the property would change hands between a willing buyer and seller, each having knowledge of the relevant facts. FMV is generally determined by competent appraisal.")
    (N416 . "The fair market value (FMV) is the price at which the property would change hands between a willing buyer and seller, each having knowledge of the relevant facts. The FMV after a theft is zero if the property is not recovered. The FMV is generally determined by competent appraisal.")
    (H569 . "Form 4835 is used to report farm rental income received as a share of crops or livestock produced by your tenant if you did not materially participate in the operation or management of the farm.  Use a different copy of Form 4835 for each farm rented.")
    (N571 . "Income you received from livestock, produce, grains, and other crops based on production. Under both the cash and the accrual methods of reporting, you must report livestock or crop share rentals received in the year you convert them into money or its equivalent.")
    (N572 . "Distributions received from a cooperative. This includes patronage dividends, nonpatronage distributions, per-unit retain allocations, and redemption of nonqualified notices and perunit retain allocations. Reported on Form 1099-PATR.")
    (N573 . "Government payments received for: price support payments, market gain from the repayment of a secured Commodity Credit Corporation (CCC) loan for less than the original loan amount, diversion payments, cost-share payments (sight drafts), payments in the form of materials (such as fertilizer or lime) or services (such asgrading or building dams). Reported on Form 1099-G.")
    (N574 . "Generally, you do not report CCC loan pro-ceeds as income. However, if you pledge part or all of your production to secure a CCC loan, you may elect to report the loan proceeds as income in the year you receive them, instead of the year you sell the crop.")
    (N575 . "The full amount forfeited or repaid with certificates, even if you reported the loan proceeds as income.  See IRS Pub 225.")
    (N576 . "You generally include crop insurance proceeds in the year you receive them. Treat as crop insurance proceeds the crop disaster payments you receive from the federal government.")
    (N577 . "If you use the cash method of accounting and receive crop insurance proceeds in the same tax year in which the crops are damaged, you can choose to postpone reporting the proceeds as income until the following tax year. A statement must also be attached to your return.  See IRS Pub 225.")
    (N578 . "Illegal Federal irrigation subsidies, bartering income, income from discharge of indebtedness, state gasoline or fuel tax refund, the gain or loss on the sale of commodity futures contracts, etc.")
    (N579 . "The business portion of car or truck expenses, such as, for gasoline, oil, repairs, insurance, tires, license plates, etc.")
    (N580 . "Chemicals used in operating your farm, such as insect sprays and dusts.")
    (N581 . "Your expenses for soil or water conservation or for the prevention of erosion of land used in farming. To take this deduction, your expenses must be consistent with a plan approved by the Natural Resources Conservation Service (NRCS) of the Department of Agriculture.")
    (N582 . "Amounts you paid for custom hire (machine work) (the machine operator furnished the equipment).  Do not include amounts paid for rental or lease of equipment you operated yourself.")
    (N583 . "Contributions to employee benefit programs, such as accident and health plans, group-term life insurance, and dependent care assistance programs. Do not include contributions  that are a incidental part of a pension or profit-sharing plan.")
    (N584 . "The cost of feed for your livestock. Generally, you cannot currently deduct ex-penses for feed to be consumed by your livestock in a later tax year. See insctuctions for Schedule F.")
    (N585 . "The cost of fertilizer, lime, and other materials applied to farm land to enrich, neutralize, or condition it. You can also deduct the cost of applying these materials. However, see Prepaid Farm Supplies, in Pub 225, for a rule that may limit your deduction for these materials.")
    (N586 . "The costs of freight or trucking of produce or livestock.")
    (N587 . "The costs of gas, fuel, oil, etc. for farm equipment.")
    (N588 . "Premiums paid for farm busines insurance, such as: fire, storm, crop, theft and liability protection of farm assets.  Do not include premiums for employee accident and health insurance.")
    (N589 . "The interest you paid to banks or other financial institutions for which you received a Form 1098, for a mortgage on real property used in your farming business (other than your main home). If you paid interest on a debt secured by your main home, and any proceeds from that debt were used in your farming operation, refer to IRS Pub 225.")
    (N590 . "The interest you paid for which you did not receive a Form 1098 (perhaps someone else did, and you are liable too), for a mortgage or other loans for your farm business.")
    (N591 . "The amounts you paid for farm labor. Do not include amounts paid to yourself.  Count the cost of boarding farm labor but not the value of any products they used from the farm. Count only what you paid house-hold help to care for farm laborers.")
    (N592 . "Enter your deduction for contributions to employee pension, profit-sharing, or annuity plans. If the plan included you as a self-employed person, see the instructions for Schedule C (Form 1040).")
    (N593 . "The business portion of your rental cost, for rented or leased vehicles, machinery, or equipment. But if you leased a vehicle for a term of 30 days or more, you may have to reduce your deduction by an inclusion amount. For details, see the instructions for Schedule C (Form 1040).")
    (N594 . "Amounts paid to rent or lease property such as pasture or farm land.")
    (N595 . "Amounts you paid for repairs and maintenance of farm buildings, machinery, and equipment. You can also include what you paid for tools of short life or minimal cost, such as shovels and rakes.")
    (N596 . "The amounts paid for seeds and plants purchased for farming.")
    (N597 . "Amounts paid for storage and warehousing of crops, grains, etc.")
    (N598 . "Livestock supplies and other supplies, including bedding, office supplies, etc.")
    (N599 . "Real estate and personal property taxes on farm business assets; Social security and Medicare taxes you paid to match what you are required to withhold from farm employees' wages and any Federal unemployment tax paid; Federal highway use tax.")
    (N600 . "Amounts you paid for gas, electricity, water, etc., for business use on the farm. Do not include personal utilities. You cannot deduct the base rate (including taxes) of the first telephone line into your residence, even if you use it for business.")
    (N601 . "The costs of veterinary services, medicine and breeding fees.")
    (N602 . "Include all ordinary and necessary farm rental expenses not deducted elsewhere on Form 4835, such as advertising, office supplies, etc. Do not include fines or penalties paid to a government for violating any law.")
    (H425 . "Form 4952 is used to compute the amount of investment interest expense deductible for the current year and the amount, if any, to carry forward to future years.")
    (N426 . "The investment interest paid or accrued during the tax year, regardless of when you incurred the indebtedness. Investment interest is interest paid or accrued on a loan (or part of a loan) that is allocable to property held for investment.")
    (H427 . "Form 6252 is used to report income from casual sales of real or personal property when you will receive any payments in a tax year after the year of sale (i.e., installment sale).")
    (N428 . "Enter the total of any money, face amount of the installment obligation, and the FMV of other property that you received or will receive in exchange for the property sold.")
    (N429 . "Enter only mortgages or other debts the buyer assumed from the seller or took the property subject to. Do not include new mortgages the buyer gets from a bank, the seller, or other sources.")
    (N431 . "Enter all depreciation or amortization you deducted or should have deducted from the date of purchase until the date of sale. Add any section 179 expense deduction.  Several other adjustmants are allowed, See Form 6252 instructions.")
    (N432 . "Enter sales commissions, advertising expenses, attorney and legal fees, etc., in selling the property.")
    (N434 . "Enter all money and the fair market value (FMV) of any property you received in this tax year. Include as payments any amount withheld to pay off a mortgage or other debt, such as broker and legal fees. Do not include interest whether stated or unstated.")
    (N435 . "Enter all money and the fair market value (FMV) of property you received before this tax year from the sale. Include allocable installment income and any other deemed payments from prior years. Do not include interest whether stated or unstated.")
    (H441 . "Form 8815 is used to compute the amount of interest you may exclude if you cashed series EE U.S. savings bonds this year that were issued after 1989 to pay for qualified higher education costs.")
    (N442 . "Qualified higher education expenses include tuition and fees required for the enrollment or attendance of the person(s). Do not include expenses for room and board, or courses involving sports, games, or hobbies that are not part of a degree or certificate granting program.")
    (N443 . "Nontaxable educational benefits. These benefits include: Scholarship or fellowship grants excludable from income under section 117; Veterans' educational assistance benefits; Employer-provided educational assistance benefits that are not included in box 1 of your W-2 form(s); Any other payments (but not gifts, bequests, or inheritances) for educational expenses that are exempt from income tax by any U.S. law. Do not include nontaxable educational benefits paid directly to, or by, the educational institution.")
    (N444 . "Enter the total proceeds (principal and interest) from all series EE and I U.S. savings bonds issued after 1989 that you cashed during this tax year.")
    (N445 . "The face value of all post-1989 series EE bonds cashed this tax year.")
    (H536 . "Form 8829 is used only if you file a Schedule C, Profit or Loss from Business, and you meet specific requirements to deduct expenses for the business use of your home.  IRS rules are stringent for this deduction.  Refer to IRS Publication 587.")
    (N537 . "The total amount of mortgage interest that would be deductible whether or not you used your home for business (i.e., amounts allowable as itemized deductions on Schedule A, Form 1040). Form 8829 computes the deductible business portion.")
    (N538 . "The total amount of real estate taxes that would be deductible whether or not you used your home for business (i.e., amounts allowable as itemized deductions on Schedule A, Form 1040). Form 8829 computes the deductible business portion.")
    (N539 . "The total amount of insurance paid for your home, in which an area or room is used regularly and exclusively for business. Form 8829 computes the deductible business portion.")
    (N540 . "The total amount of repairs and maintenance paid for your home, in which an area or room is used regularly and exclusively for business. Form 8829 computes the deductible business portion.")
    (N541 . "The total amount of utilities paid for your home, in which an area or room is used regularly and exclusively for business.  Form 8829 computes the deductible business portion.")
    (N542 . "If you rent rather than own your home, include rent paid for your home, in which an area or room is used regularly and exclusively for business. Form 8829 computes the deductible business portion.")
    (H639 . "Form 8863 is used to compute the Hope and Lifetime Learning education credits. IRS rules are stringent for these credits.  Refer to IRS Publication 970 for more information.")
    (N637 . "Expenses qualified for the Hope credit are amounts paid this tax year for tuition and fees required for the student's enrollment or attendance at an eligible educational institution.")
    (N638 . "Expenses qualified for the Lifetime Learning credit are amounts paid this tax year for tuition and fees required for the student's enrollment or attendance at an eligible educational institution.")
    (H446 . "Schedule K-1 is used to report your share of a partnership's income, credits, deductions, etc.  Use a separate copy of Schedule K-1 for each partnership.")
    (N448 . "Your share of the ordinary income (loss) from the trade or business activities of the partnership. This is reported to you on Schedule K-1. (You usually report this on Schedule E, See instructions for Schedule K-1)")
    (N449 . "The income or (loss) from rental real estate activities engaged in by the partnership. This is reported to you on Schedule K-1. (You usually report this on Schedule E, See instructions for Schedule K-1)")
    (N450 . "The income or (loss) from rental activities, other than the rental of real estate.  This is reported to you on Schedule K-1. (You usually report this on Schedule E, See instructions for Schedule K-1)")
    (N451 . "The amount of interest income the partnership reported to you on Schedule K-1. (You report this on Schedule B)")
    (N452 . "The amount of dividend income the partnership reported to you on Schedule K-1. (You report this on Schedule B)")
    (N527 . "The amount of the royalty income the partnership reported to you on Schedule K-1. (You report this on Schedule E)")
    (N453 . "The short-term gain or (loss) from sale of assets the partnership reported to you on K-1. (You report this on Schedule D)")
    (N454 . "The long-term gain or (loss) from the sale of assets the partnership reported to you on Schedule K-1. (You report this on Schedule D)")
    (N455 . "A guaranteed payments the partnership reported to you on Schedule K-1. (You report this on Schedule E)")
    (N456 . "The gain or (loss) from sale of Section 1231 assets the partnership reported to you on Schedule K-1. (You report this on Form 4797)")
    (N528 . "The amount of tax-exempt interest income the partnership reported to you on Schedule K-1. (You report this on Form 1040)")
    (H458 . "Form W-2 is used by your employer to report the amount of wages and other compensation you earned as an employee, and the amount of federal and state taxes withheld and fringe benefits received. Use a separate copy of Form W-2 for each employer.")
    (N460 . "The total wages, tips, and other compensation, before any payroll deductions, you receive from your employer.")
    (N461 . "The amount of Federal income tax withheld from your wages for the year.")
    (N462 . "The amount of social security taxes withheld from your wages.")
    (N480 . "The amount of Medicare taxes withheld from your wages.")
    (N463 . "The amount of local taxes withheld from your wages.")
    (N464 . "The amount of state taxes withheld from your wages.")
    (N465 . "The amount dependent care benefits, including the fair market value of employer-provided or employer-sponsored day-care facilities you recieved.")
    (N506 . "The total wages, tips, and other compensation, before any payroll deductions, your spouse receives from yourr spouse's employer.")
    (N507 . "The amount of Federal income tax withheld from your spouse's wages for the year.")
    (N508 . "The amount of social security taxes withheld from your spouse's wages.")
    (N510 . "The amount of Medicare taxes withheld from your spouse's wages.")
    (N509 . "The amount of local taxes withheld from your spouse's wages.")
    (N511 . "The amount of state taxes withheld from your spouse's wages.")
    (N512 . "The amount dependent care benefits, including the fair market value of employer-provided or employer-sponsored day-care facilities your spouse recieved.")
    (N546 . "Qualified moving expense reimbursements paid directly to your spouse by your spouse's employer.")
    (H547 . "Form W-2G is used to report certain gambling winnings.")
    (N549 . "The amount of gross winnings from gambling.  This may include winnings from horse racing, dog racing, jai alai, lotteries, keno, bingo, slot machines, sweepstakes, and wagering pools. If the amount is large enough, it will be reported on Form W-2G.")
    (N550 . "The amount of federal income taxes withheld from gross gambling winnings.")
    (N551 . "The amount of state income taxes withheld from gross gambling winnings.")
    (H553 . "Form 1099-MISC is used to report miscellaneous income received and direct sales of consumer goods for resale.")
    (N555 . "Amounts recieved for all types of rents, such as real estate rentals for office space, machine rentals, and pasture rentals.")
    (N556 . "The gross royalty payments recieved from a publisher or literary agent.")
    (N557 . "The amount of prizes and awards that are not for services performed. Included is the fair market value of merchandise won on game shows. Included is all punitive damages, any damages for nonphysical injuries or sickness, and any other taxable damages, Deceased employee's wages paid to estate or beneficiary.")
    (N558 . "The amount of federal income tax withheld (backup withholding) from 1099-MISC income.")
    (N559 . "Your share of all proceeds from the sale of a catch or the fair market value of a distribution in kind that you recieved as a crew member of a fishing boat.")
    (N560 . "The amount of payments recieved as a physician or other supplier or provider of medical or health care services. This includes payments made by medical and health care insurers under health, accident, and sickness insurance programs.")
    (N561 . "The amount of non-employee compensation received. This includes fees, commissions, prizes and awards for services performed, other forms of compensation for services you performed for a trade or business by which you are not employed.  Also include oil and gas payments for a working interest.")
    (N562 . "The amount of crop insurance proceeds as the result of crop damage.")
    (N563 . "The amount of state income tax withheld (state backup withholding) from 1099-MISC income.")
    (H473 . "Form 1099-R is used to report taxable and non-taxable retirement distributions from retirement, pension, profit-sharing, or annuity plans. Use a separate Form 1099-R for each payer.")
    (N475 . "The gross amount of a distribution from a qualified pension or annuity plan. Note: IRA distributions are not included here.")
    (N476 . "The taxable amount of a distribution from a qualified pension or annuity plan. Note: IRA distributions are not included here.")
    (N529 . "The amount of federal income taxes withheld from your pension distribution.")
    (N530 . "The amount of state income taxes withheld from your pension distribution.")
    (N531 . "The amount of local income taxes withheld from your pension distribution.")
    (N477 . "The gross amount of a distribution from a qualified Individual Retirement Arrangement (IRA) plan.")
    (N478 . "The taxable amount of a distribution from a qualified Individual Retirement Arrangement (IRA) plan.")
    (N532 . "The amount of federal income taxes withheld from your IRA distribution.")
    (N533 . "The amount of state income taxes withheld from your IRA distribution.")
    (N534 . "The amount of local income taxes withheld from your IRA distribution.")
    (N607 . "Contributions made to your medical savings account that were not reported on your Form W-2.")
    (N608 . "Contributions made to your spouse's medical savings account that were not reported on their Form W-2.")
    (N609 . "Contributions made to your SIMPLE retirement plan that were not reported on your Form W-2.")
    (N610 . "Contributions made to your spouse's SIMPLE retirement plan that were not reported on your spouse's Form W-2.")
    (N611 . "The amount of federal income taxes withheld from your part of any monthly benefit under title II of the Social Security Act.")
    (N612 . "The amount of federal income taxes withheld from your spouse's part of any monthly benefit under title II of the Social Security Act.")
    (N613 . "The amount of federal income taxes withheld from your part of tier I railroad retirement benefits, which are treated as a social security benefits.")
    (N614 . "The amount of federal income taxes withheld from your spouse's part of tier I railroad retirement benefits, which are treated as a social security benefits.")
    (N615 . "The amount of federal income taxes withheld from dividend income. This is usually reported on Form 1099-DIV.")
    (N616 . "The amount of federal income taxes withheld from interest income. This is usually reported on Form 1099-INT.")
    (H617 . "Form 8839 is used to report qualified adoption expenses.")
    (N618 . "Adoption fees that are reasonable and necessary, directly related to, and for the principal purpose of, the legal adoption of an eligible child.")
    (N619 . "Court costs that are reasonable and necessary, directly related to, and for the principal purpose of, the legal adoption of an eligible child.")
    (N620 . "Attorney fees that are reasonable and necessary, directly related to, and for the principal purpose of, the legal adoption of an eligible child.")
    (N621 . "Traveling expenses (including meals and lodging) while away from home, directly related to, and for the principal purpose of, the legal adoption of an eligible child.")
    (N622 . "Other expenses that are reasonable and necessary, directly related to, and for the principal purpose of, the legal adoption of an eligible child.")
    (N623 . "The gross amount of a distribution received from a qualified SIMPLE pension plan.")
    (N624 . "The taxable amount of a distribution received from a qualified SIMPLE plan. This amount may be subject to a federal penalty of up to 25%.")
    (N625 . "The amount of federal income taxes withheld from a SIMPLE distribution received.")
    (N626 . "The amount of state income taxes withheld from a SIMPLE distribution received.")
    (N627 . "The amount of local income taxes withheld from a SIMPLE distribution received.")
    (H629 . "Form 1099-MSA is used to report medical savings account distributions.")
    (N631 . "The amount you received this year from a Medical Savings Account. The amount may have been a direct payment to the medical service provider or distributed to you.")
    (N632 . "The earnings on any excess contributions you withdrew from an MSA by the due date of your income tax return. If you withdrew the excess, plus any earnings, by the due date of your income tax return, you must include the earnings in your income in the year you received the distribution even if you used it to pay qualified medical expenses.")
    (H634 . "Form 1099-G is used to report certain government payments from federal, state, or local governments.")
    (N605 . "If you received an overpayment of unemployment compensation this year or last and you repaid any of it this year, subtract the amount you repaid from the total amount you received.")
    (N606 . "The amount of federal income taxes withheld from your unemployment compensation.")
    (N672 . "Qualified state tuition program earnings you recieved this year.")))
